@@ -161,7 +161,7 @@ class ClBuilderUpdateAction(Action):
                       },
                      {'name': 'eix_update',
                       'message': __("Updating the eix cache for "
-                                    "{cl_builder_repository_name}"),
+                                    "{cl_builder_eix_repositories}"),
                       'method': 'Builder.eixUpdate(cl_builder_repository_name)',
                       'condition': (lambda Get: (
                           Get('builder.cl_builder_outdate_set') == 'on' and
