@@ -1549,6 +1549,7 @@ class VariableClBuilderFlashDev(ReadonlyVariable):
                 return ""
         return ""
 
+
 class VariableClBuilderFlashPath(ReadonlyVariable):
     """
     Путь, куда подключена flash (загрузка либо с флешки, либо с iso)
@@ -1579,10 +1580,12 @@ class VariableClBuilderFlashUuid(ReadonlyVariable):
                     install_os_disk_dev=dev, limit=1)
         return ""
 
+
 class VariableClBuilderGrubRefreshSet(ReadonlyVariable):
     """
     Обновить меню grub (HDD c включенным LiveHDD или isoscan-grub
     """
+
     def get(self):
         root_type_ext = self.Get('os_root_type_ext')
         action = self.Get('cl_action')
@@ -1601,3 +1604,15 @@ class VariableClBuilderGrubRefreshSet(ReadonlyVariable):
                 if isoimage_dir == rep_dir:
                     return "on"
         return "off"
+
+
+class VariableClBuilderEixRepositories(ReadonlyVariable):
+    """
+    Отображаемый список обновляемых репозиториев eix
+    """
+
+    def get(self):
+        return ", ".join(
+            x for x in chain(
+                reversed(self.Get('update.cl_update_rep_name')),
+                self.Get('builder.cl_builder_other_rep_name')))
