@@ -18,6 +18,7 @@ import re
 import sys
 from calculate.lib.utils.common import getTupleVersion
 from calculate.lib.utils.portage import isPkgInstalled
+from calculate.lib.utils.tools import ReverseKey
 from calculate.lib.variables.linux import LinuxDataVars
 from calculate.install.distr import IsoDistributive, DistributiveError
 from calculate.lib.utils.files import listDirectory
@@ -139,14 +140,14 @@ class VariableClBuilderImageData(ReadonlyTableVariable):
             # build
             else:
                 return (0, m.group(3),
-                        -int(m.group(5)) if m.group(5) else 0, m.group(1),
-                        m.group(6))
+                        -int(m.group(5)) if m.group(5) else 0,
+                        ReverseKey(m.group(1)), m.group(6))
         else:
             m = self.ver_parser.search(x)
             if m:
-                return -1, getTupleVersion(m.group(2)), m.group(1)
+                return -1, getTupleVersion(m.group(2)), ReverseKey(m.group(1))
             else:
-                return -2, x,
+                return -2, ReverseKey(x),
 
     def generator(self, isopath):
         n = 1
