@@ -152,9 +152,9 @@ class VariableClBuilderLinuxDatavars(ReadonlyVariable):
     def source_data(self):
         image = self.Get('cl_builder_source')
         image_fn = self.Get('cl_builder_source_filename')
-        return self.get_data(image, image_fn=image_fn)
+        return self.get_data(image, image_fn=image_fn, source=True)
 
-    def get_data(self, image, image_fn=None):
+    def get_data(self, image, image_fn=None, source=False):
         if image:
             if isinstance(image, distr.ArchiveDistributive):
                 return DataVarsBuilderLinux.StageInformation(image_fn)
@@ -164,6 +164,8 @@ class VariableClBuilderLinuxDatavars(ReadonlyVariable):
                     dvbl = DataVarsBuilderLinux(systemRoot=distr_dn)
                     dvbl['cl_update_binhost_recheck_set'] = \
                         self.Get('update.cl_update_binhost_recheck_set')
+                    if source:
+                        dvbl.cache['cl_update_binhost_data'] = [[]]
                     dvbl.prepare_all()
                     return dvbl
         else:
